function [phat, qhat, income_long, shares_long, fw_long, period_long, x0_long, ...
            p0_long, Nyear_long] = MC_unconstrained(budgets_all,shares_all,income_all, ...
                            medexp_all, budget_n, budget_l)
%---------------------------------------------------------------
% PURPOSE: generates the kernel weights required to construct unconstrained
% nonparametric demand estimates at the budgets of interest
%---------------------------------------------------------------

K = size(budgets_all, 2);
p_ = budgets_all'.*repmat(medexp_all, K, 1);
T = budget_l;
p_norm = p_./repmat(p_(K,:), K, 1);

% for the estimation 
qhat = NaN(K, T, budget_n);
phat = NaN(K, T, budget_n);
x0_long = NaN(1, T, budget_n);

% for recording 
income_long{budget_n} = [];
shares_long{budget_n} = [];
fw_long{budget_n} = [];
period_long{budget_n} = [];
p0_long{budget_n} = [];
Nyear_long{budget_n}=[];

for s = 1 : budget_n
    q_ = NaN(K, T);
    pp = p_norm(:, s:s+budget_l-1);
    x0 = NaN(1,T);

    income_long_ = [];
    shares_long_ = [];
    period_long_ = [];
    Nyear_long_ = NaN(1, T);
    for t = 1 : T
        y = income_all{s + t -1}/pp(K,t);
        
        log_xx = log(y);
        if t == 1
            x_= median(y);
        else
            x_ = pp(:,t)'*q_(:,t-1);
        end
        x0(t) = x_;
        
        bs = shares_all{s + t -1};        
        fw_ = NaN(length(y), K-1);
        for k = 1 : K-1
            [~,~,fw] = Kreg(log_xx, bs(:,k), log(x_));
            fw_(:,k) = fw;
        end
        tmp = sum(fw_, 2);
        f = find(tmp > .00005);
        
        bs_ = NaN(K,1);
        bs_(1:K-1,:) = sum(fw_(f,:))';
        bs_(K,:) = 1 - sum(bs_(1:2,:));
        
        q_(:,t) = (x_*bs_)./pp(:,t); 
        
        
        % keeping track
        income_long_ = [income_long_; y(f)];
        period_long_ = [period_long_; t*ones(length(f), 1)];
        shares_long_ = [shares_long_; bs(f,:)];
        if t == 1               
            for_weights_1 = fw_(f,1);
            for_weights_2 = fw_(f,2);
        else
            for_weights_1 = [[for_weights_1; zeros(length(f),t-1)] ...
                [zeros(size(for_weights_1, 1), 1); fw_(f,1)]];
            for_weights_2 = [[for_weights_2; zeros(length(f),t-1)] ...
                [zeros(size(for_weights_2, 1), 1); fw_(f,2)]];
        end
        Nyear_long_(t) = length(f);
    end
    
    for_weights = zeros(length(income_long_), T, K-1);
    for_weights(:,:,1) = for_weights_1.*repmat(x0./pp(1,:), length(income_long_), 1);
    for_weights(:,:,2) = for_weights_2.*repmat(x0./pp(2,:), length(income_long_), 1);
    
    % recording 
    qhat(:, :, s) = q_;
    phat(:, :, s) = pp;
    
    income_long{s} = income_long_;
    shares_long{s} = shares_long_;
    fw_long{s} = for_weights;
    period_long{s} = period_long_;
    x0_long(1,:,s) = x0;
    p0_long{s} = pp;
    Nyear_long{s} = Nyear_long_;
end

return