
function [A, b, C, d, ctype, Aeq, beq, lb, ub] = mutcon_constraints_extrans...
    (for_weights, p0, x0_, N_year)

%---------------------------------------------------------------
% PURPOSE: generates the matrices required to impose mutual consistency
%---------------------------------------------------------------

    B = size(p0, 2);
    N = size(for_weights, 1);

    % constraint : budget constraint: quantities of 1 and 2 must sum to less than x
    BC_A = repmat(p0(1,:)', 1, N).*for_weights(:,:,1)' ...
        + repmat(p0(2,:)', 1, N).*for_weights(:,:,2)';
    BC_b = x0_';
    
    % Constraint 3
    w3_A = zeros(B*(B-1), N);
    R3_A = zeros(B*(B-1));
    R3_b = zeros(B*(B-1),1);
    for b = 1 : B
        
        R3_A((b-1)*(B-1) + 1: b*(B-1), (b-1)*(B-1) + 1: b*(B-1)) = -(x0_(b)+.001)*eye(B-1);
        R3_b((b-1)*(B-1) + 1: b*(B-1), 1) = -(x0_(b)+.001) + (p0(3,b)*x0_(1,setdiff(1:B,b))./p0(3,setdiff(1:B,b)))';
        
        w3_A((b-1)*(B-1) + 1: b*(B-1),:) = ...
            repmat((p0(3,b)*(p0(1,setdiff(1:B,b))./p0(3,setdiff(1:B,b))) - p0(1,b))', 1, N).*for_weights(:,setdiff(1:B,b),1)' ...
            + repmat((p0(3,b)*(p0(2,setdiff(1:B,b))./p0(3,setdiff(1:B,b))) - p0(2,b))', 1, N).*for_weights(:,setdiff(1:B,b),2)';

    end
    
     % Constraint 5
    w5_A = zeros(B*(B-1), N);
    R5_A = zeros(B*(B-1));
    R5_b = zeros(B*(B-1),1);
    for a = 1 : B
        
        R5_A((a-1)*(B-1) + 1: a*(B-1), (a-1)*(B-1) + 1: a*(B-1)) = diag(x0_(1, setdiff(1:B, a))');
        R5_b((a-1)*(B-1) + 1: a*(B-1), 1) = (p0(3,setdiff(1:B, a))*x0_(1,a)./p0(3,a))';
        
        w5_A((a-1)*(B-1) + 1: a*(B-1),:) = ...
            repmat((p0(3,setdiff(1:B, a))*(p0(1,a)./p0(3,a)) - p0(1,setdiff(1:B, a)))', 1, N).*repmat(for_weights(:,a,1)', B-1, 1) ...
            + repmat((p0(3,setdiff(1:B, a))*(p0(2,a)./p0(3,a)) - p0(2,setdiff(1:B, a)))', 1, N).*repmat(for_weights(:,a,2)', B-1, 1);
    end
    
    combs = combnk(1:B, 3);
    Nc = 6*size(combs, 1); 
    R4_A = zeros(Nc, B*(B-1));
    R4_b = ones(Nc, 1);
    index=1;
    for b = 1 : size(combs, 1)
        opts = perms(combs(b,:));
        for i = 1 : size(opts, 1)
            R4_A(index, (opts(i,1) - 1)*(B-1) + (opts(i, 2) < opts(i, 1))*opts(i,2) ...
                                              +  (opts(i, 2) > opts(i, 1))*(opts(i,2) - 1)) = 1;
            R4_A(index, (opts(i,2) - 1)*(B-1) + (opts(i, 3) < opts(i, 2))*opts(i,3) ...
                                              +  (opts(i, 3) > opts(i, 2))*(opts(i,3) - 1)) = 1;  
            R4_A(index, (opts(i,1) - 1)*(B-1) + (opts(i, 3) < opts(i, 1))*opts(i,3) ...
                                               + (opts(i, 3) > opts(i, 1))*(opts(i,3) - 1)) = -1;   
            index = index + 1;                                 
        end
    end
    
    % bring together
    BC = [BC_A zeros(B, B*(B-1))];
    con3 = [w3_A R3_A];
    con5 = [w5_A R5_A ];
    con4 = [zeros(Nc, N) R4_A];
   
    
    clear BC_A w3_A R3_A w5_A R5_A R4a_A ua_A R4b_A ub_A
    
    A = [ con3; con5; con4; BC];
    b = [R3_b; R5_b; R4_b; BC_b];
    
    clear BC con3 con5 con4a con4b BC_b R3_b R5_b R4a_b R4b_b
    
    % objective  
    tmp = zeros(N + B*(B-1), 1);
    tmp(1:N,1) = ones(N, 1);
    C= diag(tmp);
    clear tmp
    d = zeros(N + B*(B-1), 1);
    d(1:N) = ones(N, 1);

       
    s1 = 'C';
    for i = 2 : N
        s2 = 'C';
        s1 = strcat(s1, s2);
    end
    s1 = strcat(s1, 'B');
    for i = 2 : B*(B-1)
        s2 = 'B';
        s1 = strcat(s1, s2);
    end
    ctype = s1;
    
    
    % weights sum to on1 
    Aeq = zeros(size(N_year, 2), size(A, 2));
    beq = N_year';    
    index = 0;
    for t = 1 : length(N_year)
        Aeq(t, index+1:index + N_year(t)) = ones(1, N_year(t));
        index = index + N_year(t);
    end
    
    lb = zeros(size(A, 2), 1);
    ub= ones(size(A, 2), 1);
 return